@@ -2,7 +2,6 @@
 
 """telegram_menu demonstrator."""
 
-import logging
 from pathlib import Path
 
 from telegram_menu import TelegramMenuSession
@@ -11,11 +10,12 @@ from tests.test_connection import MyNavigationHandler, StartMessage, init_logger
 
 def run() -> None:
     """Run the demo example."""
-    init_logger()
+    logger = init_logger(__name__)
+
     with (Path.home() / ".telegram_menu" / "key.txt").open() as key_h:
         api_key = key_h.read().strip()
 
-    logging.info(" >> Start the demo and wait forever, quit with CTRL+C...")
+    logger.info(" >> Start the demo and wait forever, quit with CTRL+C...")
     TelegramMenuSession(api_key).start(start_message_class=StartMessage, navigation_handler_class=MyNavigationHandler)
 
 
